@@ -29,14 +29,17 @@ SEXP ichimoku_PeriodsSymbol;
 SEXP ichimoku_PeriodicitySymbol;
 SEXP ichimoku_TickerSymbol;
 
+SEXP ichimoku_dfclass;
 SEXP ichimoku_klass;
 SEXP ichimoku_tclass;
-SEXP ichimoku_tzone;
 SEXP ichimoku_int_zero;
 SEXP ichimoku_int_three;
 
-typedef SEXP (*c_fun) (SEXP);
-typedef SEXP (*rcpp_fun) (SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+typedef SEXP (*one_fun) (SEXP);
+typedef SEXP (*twelve_fun) (SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+
+one_fun naofun;
+twelve_fun jsofun;
 
 // rolling max over a window
 SEXP _wmax(const SEXP x, const SEXP window) {
@@ -182,14 +185,14 @@ SEXP _tbl(const SEXP x, const SEXP type) {
   PROTECT(dn2 = VECTOR_ELT(Rf_getAttrib(x, R_DimNamesSymbol), 1));
   R_xlen_t dlen = Rf_xlength(dn2);
   PROTECT(names = Rf_allocVector(STRSXP, dlen + 1));
-  SET_STRING_ELT(names, 0, Rf_mkChar("index"));
+  SET_STRING_ELT(names, 0, Rf_mkCharLenCE("index", 5, CE_NATIVE));
   for (R_xlen_t i = 0; i < dlen; i++) {
     SET_STRING_ELT(names, i + 1, STRING_ELT(dn2, i));
   }
   Rf_namesgets(tbl, names);
   UNPROTECT(2);
 
-  Rf_classgets(tbl, Rf_mkString("data.frame"));
+  Rf_classgets(tbl, ichimoku_dfclass);
 
   if (xlen <= INT_MAX) {
     rownames = Rf_allocVector(INTSXP, 2);
@@ -221,7 +224,7 @@ SEXP _tbl(const SEXP x, const SEXP type) {
 SEXP _create(SEXP kumo, SEXP xtsindex, const SEXP periods,
              const SEXP periodicity, const SEXP ticker, const SEXP x) {
 
-  Rf_setAttrib(xtsindex, xts_IndexTzoneSymbol, ichimoku_tzone);
+  Rf_setAttrib(xtsindex, xts_IndexTzoneSymbol, R_BlankScalarString);
   Rf_setAttrib(xtsindex, xts_IndexTclassSymbol, ichimoku_tclass);
   Rf_setAttrib(kumo, xts_IndexSymbol, xtsindex);
 
@@ -290,15 +293,15 @@ SEXP _df(const SEXP x) {
   PROTECT(dn2 = VECTOR_ELT(Rf_getAttrib(x, R_DimNamesSymbol), 1));
   R_xlen_t dlen = Rf_xlength(dn2);
   PROTECT(names = Rf_allocVector(STRSXP, dlen + 2));
-  SET_STRING_ELT(names, 0, Rf_mkChar("index"));
+  SET_STRING_ELT(names, 0, Rf_mkCharLenCE("index", 5, CE_NATIVE));
   for (R_xlen_t i = 0; i < dlen; i++) {
     SET_STRING_ELT(names, i + 1, STRING_ELT(dn2, i));
   }
-  SET_STRING_ELT(names, dlen + 1, Rf_mkChar("idx"));
+  SET_STRING_ELT(names, dlen + 1, Rf_mkCharLenCE("idx", 3, CE_NATIVE));
   Rf_namesgets(df, names);
   UNPROTECT(2);
 
-  Rf_classgets(df, Rf_mkString("data.frame"));
+  Rf_classgets(df, ichimoku_dfclass);
 
   if (xlen <= INT_MAX) {
     rownames = Rf_allocVector(INTSXP, 2);
@@ -343,14 +346,12 @@ SEXP _coredata(const SEXP x) {
 
 // imports from the package 'xts'
 SEXP _naomit(SEXP x) {
-  c_fun fun = (c_fun) R_GetCCallable("xts", "na_omit_xts");
-  return fun(x);
+  return naofun(x);
 }
 
 // imports from the package 'RcppSimdJson'
 SEXP _deserialize_json(SEXP json, SEXP query) {
-  rcpp_fun fun = (rcpp_fun) R_GetCCallable("RcppSimdJson", "_RcppSimdJson_.deserialize_json");
-  return fun(json, query, R_NilValue, R_NilValue, R_NilValue, Rf_ScalarLogical(0), R_NilValue, Rf_ScalarLogical(0), R_NilValue, ichimoku_int_three, ichimoku_int_zero, ichimoku_int_zero);
+  return jsofun(json, query, R_NilValue, R_NilValue, R_NilValue, Rf_ScalarLogical(0), R_NilValue, Rf_ScalarLogical(0), R_NilValue, ichimoku_int_three, ichimoku_int_zero, ichimoku_int_zero);
 }
 
 // package level registrations
@@ -361,9 +362,12 @@ static void RegisterSymbols(void) {
   ichimoku_PeriodsSymbol = Rf_install("periods");
   ichimoku_PeriodicitySymbol = Rf_install("periodicity");
   ichimoku_TickerSymbol = Rf_install("ticker");
+  naofun = (one_fun) R_GetCCallable("xts", "na_omit_xts");
+  jsofun = (twelve_fun) R_GetCCallable("RcppSimdJson", "_RcppSimdJson_.deserialize_json");
 }
 
 static void PreserveObjects(void) {
+  R_PreserveObject(ichimoku_dfclass = Rf_mkString("data.frame"));
   R_PreserveObject(ichimoku_klass = Rf_allocVector(STRSXP, 3));
   SET_STRING_ELT(ichimoku_klass, 0, Rf_mkChar("ichimoku"));
   SET_STRING_ELT(ichimoku_klass, 1, Rf_mkChar("xts"));
@@ -371,7 +375,6 @@ static void PreserveObjects(void) {
   R_PreserveObject(ichimoku_tclass = Rf_allocVector(STRSXP, 2));
   SET_STRING_ELT(ichimoku_tclass, 0, Rf_mkChar("POSIXct"));
   SET_STRING_ELT(ichimoku_tclass, 1, Rf_mkChar("POSIXt"));
-  R_PreserveObject(ichimoku_tzone = Rf_mkString(""));
   R_PreserveObject(ichimoku_int_zero = Rf_ScalarInteger(0));
   R_PreserveObject(ichimoku_int_three = Rf_ScalarInteger(3));
 }
@@ -379,9 +382,9 @@ static void PreserveObjects(void) {
 static void ReleaseObjects(void) {
   R_ReleaseObject(ichimoku_int_three);
   R_ReleaseObject(ichimoku_int_zero);
-  R_ReleaseObject(ichimoku_tzone);
   R_ReleaseObject(ichimoku_tclass);
   R_ReleaseObject(ichimoku_klass);
+  R_ReleaseObject(ichimoku_dfclass);
 }
 
 static const R_CallMethodDef CallEntries[] = {
